@@ -31,7 +31,7 @@ from coverage.exceptions import CoverageException, DataError
 from coverage.files import PathAliases
 from coverage.misc import file_be_gone, isolate_module
 from coverage.numbits import numbits_to_nums, numbits_union, nums_to_numbits
-from coverage.types import TArc, TDebugCtl, TLineNo, TWarnFn
+from coverage.types import FilePath, TArc, TDebugCtl, TLineNo, TWarnFn
 from coverage.version import __version__
 
 os = isolate_module(os)
@@ -197,9 +197,11 @@ class CoverageData(AutoReprMixin):
 
     Write the data to its file with :meth:`write`.
 
-    You can clear the data in memory with :meth:`erase`.  Two data collections
-    can be combined by using :meth:`update` on one :class:`CoverageData`,
-    passing it the other.
+    You can clear the data in memory with :meth:`erase`.  Data for specific
+    files can be removed from the database with :meth:`purge_files`.
+
+    Two data collections can be combined by using :meth:`update` on one
+    :class:`CoverageData`, passing it the other.
 
     Data in a :class:`CoverageData` can be serialized and deserialized with
     :meth:`dumps` and :meth:`loads`.
@@ -212,7 +214,7 @@ class CoverageData(AutoReprMixin):
 
     def __init__(
         self,
-        basename: Optional[str] = None,
+        basename: Optional[FilePath] = None,
         suffix: Optional[Union[str, bool]] = None,
         no_disk: bool = False,
         warn: Optional[TWarnFn] = None,
@@ -596,7 +598,7 @@ class CoverageData(AutoReprMixin):
         """
         self.touch_files([filename], plugin_name)
 
-    def touch_files(self, filenames: Iterable[str], plugin_name: Optional[str] = None) -> None:
+    def touch_files(self, filenames: Collection[str], plugin_name: Optional[str] = None) -> None:
         """Ensure that `filenames` appear in the data, empty if needed.
 
         `plugin_name` is the name of the plugin responsible for these files.
@@ -615,6 +617,30 @@ class CoverageData(AutoReprMixin):
                     # Set the tracer for this file
                     self.add_file_tracers({filename: plugin_name})
 
+    def purge_files(self, filenames: Collection[str]) -> None:
+        """Purge any existing coverage data for the given `filenames`.
+
+        .. versionadded:: 7.2
+
+        """
+        if self._debug.should("dataop"):
+            self._debug.write(f"Purging data for {filenames!r}")
+        self._start_using()
+        with self._connect() as con:
+
+            if self._has_lines:
+                sql = "delete from line_bits where file_id=?"
+            elif self._has_arcs:
+                sql = "delete from arc where file_id=?"
+            else:
+                raise DataError("Can't purge files in an empty CoverageData")
+
+            for filename in filenames:
+                file_id = self._file_id(filename, add=False)
+                if file_id is None:
+                    continue
+                con.execute_void(sql, (file_id,))
+
     def update(self, other_data: CoverageData, aliases: Optional[PathAliases] = None) -> None:
         """Update this data with data from several other :class:`CoverageData` instances.
 
@@ -832,7 +858,12 @@ class CoverageData(AutoReprMixin):
         return bool(self._has_arcs)
 
     def measured_files(self) -> Set[str]:
-        """A set of all files that had been measured."""
+        """A set of all files that have been measured.
+
+        Note that a file may be mentioned as measured even though no lines or
+        arcs for that file are present in the data.
+
+        """
         return set(self._file_map)
 
     def measured_contexts(self) -> Set[str]:
